python_apigen demo
==================

Indexing
--------

.. python-apigen-group:: indexing

Some other group
----------------

.. python-apigen-group:: some-other-group

Type parameter demo
-------------------

.. python-apigen-group:: type-param
